@@ -1,9 +1,9 @@
 import os
-from tkinter import simpledialog, Entry, Label, W, LEFT, E, END, messagebox, Tk
-from tkinter.simpledialog import Dialog, askstring
 
 
 def get_password_with_dialog(database):
+    from tkinter import Tk
+    from tkinter.simpledialog import askstring
     os.environ['TK_SILENCE_DEPRECATION'] = '1'
     tk = Tk()
     tk.withdraw()
